@@ -5,9 +5,12 @@
 #'  outliers if they fall in the \eqn{(1- alpha)} tail of the distribution of the nearest-neighbor
 #'  distances between exemplars.
 #' @param outtail Direction of the outlier tail.
+#' @param p Proportion of possible candidates for outliers. This defines the starting point for the
+#' bottom up searching algorithm.
+#' @param tn Sample size to calculate an empirical threshold
 #' @return The indexes (or names, if the input is named vactor) of the observations determined to be outliers.
 #' @export
-find_theshold <- function(outlier_score, alpha = 0.05, outtail = c("max", "min")) {
+find_threshold <- function(outlier_score, alpha, outtail = c("max", "min"), p, tn) {
 
   n <- length(outlier_score)
   if(outtail == "min")
@@ -17,15 +20,11 @@ find_theshold <- function(outlier_score, alpha = 0.05, outtail = c("max", "min")
 
   ord <- order(outlier_score)
   gaps <- c(0, diff(outlier_score[ord]))
-  n4 <- max(min(50, floor(n / 4)), 2)
+  n4 <- max(min(tn, floor(n / 4)), 2)
   J <- 2:n4
-  start <- max(floor(n / 2), 1) + 1
+  start <- max(floor(n * (1-p)), 1) + 1
   ghat <- numeric(n)
   for (i in start:n) ghat[i] <- sum((J / (n4 - 1)) * gaps[i - J + 1 ]) # check i - j +1
-  # J <- 1:n4
-  #  start <- max(floor(n/2), 1) + 1
-  #  ghat <- numeric(n)
-  #  for (i in start:n) ghat[i] <- sum((J/(n4)) * gaps[i - J+1 ]) # check i - j +1
   logAlpha <- log(1 / alpha)
   bound <- Inf
 
